@@ -16,8 +16,8 @@
 ###
 ### You should have received a copy of the GNU General Public
 ### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
+### Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+### MA 02110-1301, USA
 
 
 
@@ -371,10 +371,17 @@ lpoints <-
              cex = plot.symbol$cex, ...)
 {
     plot.symbol <- trellis.par.get("plot.symbol")
-    lplot.xy(xy.coords(x, y), type = type,
-             col = col, pch = pch, font = font,
-             fontfamily = fontfamily, fontface = fontface,
-             cex = cex, alpha = alpha, ...)
+    lplot.xy(xy.coords(x, y),
+             type = type,
+             col = col,
+             pch = pch,
+             alpha = alpha,
+             fill = fill,
+             font = font,
+             fontfamily = fontfamily,
+             fontface = fontface,
+             cex = cex,
+             ...)
 }
 
 
