@@ -15,8 +15,8 @@
 ###
 ### You should have received a copy of the GNU General Public
 ### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
+### Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+### MA 02110-1301, USA
 
 
 
@@ -357,7 +357,7 @@ splom.data.frame <-
 
 splom.formula <-
     function(x,
-             data = parent.frame(),
+             data = NULL,
              auto.key = FALSE,
              aspect = 1,
              between = list(x = 0.5, y = 0.5),
